server/repository.py
changeset 4467 0e73d299730a
parent 4252 6c4f109c2b03
child 4517 0f3c10fc42b2
--- a/server/repository.py	Fri Feb 05 11:54:23 2010 +0100
+++ b/server/repository.py	Fri Feb 05 11:56:57 2010 +0100
@@ -1129,7 +1129,7 @@
                                eidfrom=subject, rtype=rtype, eidto=object)
         source.add_relation(session, subject, rtype, object)
         rschema = self.schema.rschema(rtype)
-        session.update_rel_cache_add(subject, rtype, object, rschema.symetric)
+        session.update_rel_cache_add(subject, rtype, object, rschema.symmetric)
         if source.should_call_hooks:
             self.hm.call_hooks('after_add_relation', session,
                                eidfrom=subject, rtype=rtype, eidto=object)
@@ -1144,9 +1144,9 @@
                                eidfrom=subject, rtype=rtype, eidto=object)
         source.delete_relation(session, subject, rtype, object)
         rschema = self.schema.rschema(rtype)
-        session.update_rel_cache_del(subject, rtype, object, rschema.symetric)
-        if rschema.symetric:
-            # on symetric relation, we can't now in which sense it's
+        session.update_rel_cache_del(subject, rtype, object, rschema.symmetric)
+        if rschema.symmetric:
+            # on symmetric relation, we can't now in which sense it's
             # stored so try to delete both
             source.delete_relation(session, object, rtype, subject)
         if source.should_call_hooks: